@@ -13,7 +13,7 @@ import urlparse
 import urllib
 from cgi import parse_qsl
 
-from .api import Readability, settings, AuthenticationError, ReadabilityShortner
+from .api import Readability, settings, AuthenticationError
 
 
 __version__ = '0.1.1'
@@ -100,9 +100,3 @@ def xauth(consumer_key, consumer_secret, username, password):
 
 
     return token
-
-
-def shortner():
-    """Returns an instance of the Shortner API."""
-
-    return ReadabilityShortner()
